@@ -23,15 +23,16 @@ class KDirOperatorDetailView : public QTreeView
 
 public:
     explicit KDirOperatorDetailView(QWidget *parent = nullptr);
-    virtual ~KDirOperatorDetailView();
+    ~KDirOperatorDetailView() override;
 
     /**
-    * Displays either Detail, Tree or DetailTree modes.
-    */
+     * Displays either Detail, Tree or DetailTree modes.
+     */
     virtual bool setViewMode(KFile::FileView viewMode);
 
 protected:
-    QStyleOptionViewItem viewOptions() const override;
+    void initViewItemOption(QStyleOptionViewItem *option) const override;
+
     bool event(QEvent *event) override;
     void dragEnterEvent(QDragEnterEvent *event) override;
     void mousePressEvent(QMouseEvent *event) override;
