@@ -939,10 +939,18 @@ void HTTPProtocol::davParsePropstats(const QDomNodeList &propstats, KIO::UDSEntr
                 }
             } else if (property.tagName() == QLatin1String("quota-used-bytes")) {
                 // Quota-used-bytes. "Contains the amount of storage already in use."
-                quotaUsed = property.text().toLongLong();
+                bool ok;
+                qlonglong used = property.text().toLongLong(&ok);
+                if (ok) {
+                    quotaUsed = used;
+                }
             } else if (property.tagName() == QLatin1String("quota-available-bytes")) {
                 // Quota-available-bytes. "Indicates the maximum amount of additional storage available."
-                quotaAvailable = property.text().toLongLong();
+                bool ok;
+                qlonglong available = property.text().toLongLong(&ok);
+                if (ok) {
+                    quotaAvailable = available;
+                }
             } else {
                 // qCDebug(KIO_HTTP) << "Found unknown webdav property:" << property.tagName();
             }
