@@ -31,14 +31,18 @@
 #include <KService>
 #include <KUrlMimeData>
 
+#ifdef WITH_QTDBUS
 #include <QDBusConnection>
 #include <QDBusPendingCall>
+#endif
+
 #include <QDropEvent>
 #include <QFileInfo>
 #include <QMenu>
 #include <QMimeData>
 #include <QProcess>
 #include <QTimer>
+#include <QWindow>
 
 using namespace KIO;
 
@@ -241,6 +245,7 @@ void DropJobPrivate::slotStart()
 {
     Q_Q(DropJob);
 
+#ifdef WITH_QTDBUS
     if (m_hasArkFormat) {
         QDBusMessage message = QDBusMessage::createMethodCall(m_remoteArkDBusClient,
                                                               m_remoteArkDBusPath,
@@ -260,6 +265,7 @@ void DropJobPrivate::slotStart()
 
         return;
     }
+#endif
 
     if (!m_urls.isEmpty()) {
         if (destIsDirectory()) {
@@ -376,6 +382,11 @@ void DropJob::showMenu(const QPoint &p, QAction *atAction)
     }
 
     for (KIO::DropMenu *menu : std::as_const(d->m_menus)) {
+        if (QWindow *transientParent = KJobWidgets::windowHandle(this)) {
+            if (menu->winId()) {
+                menu->windowHandle()->setTransientParent(transientParent);
+            }
+        }
         menu->popup(p, atAction);
     }
 }
@@ -525,6 +536,11 @@ void DropJobPrivate::slotDropActionDetermined(int error)
         });
 
         if (!(m_dropjobFlags & KIO::ShowMenuManually)) {
+            if (QWindow *transientParent = KJobWidgets::windowHandle(q)) {
+                if (menu->winId()) {
+                    menu->windowHandle()->setTransientParent(transientParent);
+                }
+            }
             menu->popup(window ? window->mapToGlobal(m_relativePos) : QCursor::pos());
         }
         m_menus.insert(menu);
